@@ -6,7 +6,3 @@ from magicapi.Errors.MagicExceptions import (
     FirestoreException,
     TwilioException,
 )
-
-os.environ["DEFAULT_EXCEPTION"] = BackendException
-
-print(os.getenv("DEFAULT_EXCEPTION"))
