@@ -24,6 +24,13 @@ def add_cors(new_app):
     )
 
 
+def add_sentry(new_app):
+    from magicapi.Services.Sentry import SentryAsgiMiddleware, HAS_SENTRY_DSN
+
+    if HAS_SENTRY_DSN:
+        new_app.add_middleware(SentryAsgiMiddleware)
+
+
 def add_tasks_and_process_time_middleware(new_app):
     from magicapi.Models.task_executor import save_tasks
     from magicapi.Models.NotFound import save_not_found_from_request
@@ -36,7 +43,8 @@ def add_tasks_and_process_time_middleware(new_app):
         print("url path", request.url.path, "***url", request.url)
         if "aws.context" in request.scope:
             context = request.scope["aws.context"]
-            context.serverless_sdk.set_endpoint(request.url.path)
+            if hasattr(context, "serverless_sdk"):
+                context.serverless_sdk.set_endpoint(request.url.path)
         response = await call_next(request)
         if response.status_code in [404, 405] and g.settings.save_calls:
             await save_not_found_from_request(request)
@@ -58,6 +66,7 @@ def add_hello_world_testing_route(new_app):
 
 def add_addons(new_app):
     add_cors(new_app)
+    add_sentry(new_app)
     add_tasks_and_process_time_middleware(new_app)
     add_hello_world_testing_route(new_app)
 
@@ -109,17 +118,13 @@ def use_route_names_as_operation_ids(app: FastAPI) -> None:
             route.operation_id = route.name
 
 
-from raven import Client  # Offical `raven` module
-from raven_python_lambda import RavenLambdaWrapper
-
-
 def create_handler(app):
-    @RavenLambdaWrapper()
     def handler(event, context):
         """Handler to give to lambda... which wraps FastAPI"""
         if event.get("source") in ["aws.events", "serverless-plugin-warmup"]:
             print("Lambda is warm, now!!!")
-            context.serverless_sdk.set_endpoint("/warmup")
+            if hasattr(context, "serverless_sdk"):
+                context.serverless_sdk.set_endpoint("/warmup")
             return {}
 
         asgi_handler = Mangum(app, api_gateway_base_path=g.settings.stage)
